# Building the documentation

If you've already [set up your environment][environment], you can build the
documentation site and watch the repo for changes:

```shell
nox -rs docs-serve
```

```{note}
Python 3.9+ is required to build the documentation.
```

[environment]: /contributing/environment
